" ===============================================================
"  TareRSS Parse
"  Kyosuke Takayama (http://espion.just-size.jp/)
"
"  $Id: tarerss-phead.vim,v 1.1.1.1 2004/08/02 03:43:20 gaba Exp $
" ===============================================================

scriptencoding euc-jp

if exists('g:tarerss_disable')
   finish
endif

" -------------------
" BASE
" -------------------

"" BASE --------------------------------------------------------------
function! TareRssParseArticle_BASE(result)
   let result = a:result

   while result != ''
      let idx = match(result, "\<NL>")
      let buf = strpart(result, 0, idx)
      let result = strpart(result, idx+1)
      call append('$', buf)
   endwhile
endfun

"" START to END ------------------------------------------------------
function! TareRssParseArticle_ste(url, enc, start, end)
   let result = system(g:tarerss_curlprg.' -s "'.a:url.'"')."\<NL>"
   if a:enc != &enc
      let result = iconv(result, a:enc, &enc)
   endif
   let result = substitute(result, '<p>', "<p>\<NL>", 'gi')
   let result = substitute(result, '<br>', "<br>\<NL>", 'gi')
   let result = substitute(result, '<h\(.\)>', '<h\1>'."\<NL>", 'gi')
   let result = substitute(result, '</h\(.\)>', '</h\1>'."\<NL>", 'gi')
   let result = substitute(result, '</div>', "\<NL></div>", 'gi')

   while result != ''
      let idx = match(result, "\<NL>")
      let buf = strpart(result, 0, idx)
      let result = strpart(result, idx+1)
      if buf =~ a:start
         let delete_flag = 0
         while result != ''
            let idx = match(result, "\<NL>")
            let buf = strpart(result, 0, idx)
            let result = strpart(result, idx+1)
            if buf =~ a:end
               break
            endif
            if g:tarerss_w3mprg == ''
               let buf = substitute(buf, '<.\{-\}>', '', 'g')
               let buf = substitute(buf, '\v^\s+', '', '')
               if delete_flag == 1
                  if buf =~ '>'
                     let buf = substitute(buf, '.*>', '', 'g')
                     let delete_flag = 0
                  else
                     let buf = ''
                  endif
               elseif buf =~ '<'
                  let delete_flag = 1
                  let buf = substitute(buf, '<.*', '', 'g')
               endif
               let buf = TareRssDecode(buf)
            endif

            call append('$', buf)
            if g:tarerss_w3mprg == ''
               while strlen(buf) > g:tarerss_textwidth
                  call cursor('$', g:tarerss_textwidth)
                  exe "normal! i\<CR>"
                  let buf = getline('.')
               endwhile
            endif
         endwhile
         break
      endif
   endwhile
endfun

" -------------------
" News Site
" -------------------

"" OSDL (Japanlinux.com) ---------------------------------------------
function! TareRssParseArticle_jlc(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', '<', '</html>')
endfun

function! TareRssParseLink_jlc(link, dummy)
   let link = substitute(a:link, '\v^http://japan.linux.com/[^/]+/(.{-}).shtml.*', '\1', '')
   let link = 'http://japan.linux.com/print.pl?sid='.link

   return link
endfun

function! TareRssParseMode_jlc(mode, dummy)
   if a:mode == 0
      return 1
   endif
   return 0
endfun

"" Asahi.com ---------------------------------------------------------
function! TareRssParseArticle_Asahi(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', 'FJZONE START NAME="HONBUN"', 'FJZONE END NAME="HONBUN"')
endfun

"" Mycom PC Web ------------------------------------------------------
function! TareRssParseArticle_PcWatch(url)
   call TareRssParseArticle_ste(a:url, 'cp932', '#BeginEditable "contents"', '#BeginEditable "RelativeArticle"')
endfun

function! TareRssParseMode_PcWatch(mode, dummy)
   if a:mode == 0
      return 1
   endif
   return 0
endfun

"" CNET --------------------------------------------------------------
function! TareRssParseArticle_CNET(url)
   call TareRssParseArticle_ste(a:url, 'cp932', '<div class="leaf_body">', '<div class="pl10 pr15 mb10">')
endfun

"" nikkeibp ----------------------------------------------------------
function! TareRssParseArticle_nikkeibp(url)
   call TareRssParseArticle_ste(a:url, 'iso-2022-jp', '<!--  end : photo and caption  -->', '<!-- begin: system transitional script -->')
endfun

function! TareRssParseLink_nikkeibp(link, dummy)
   let link = substitute(a:link, '?from=rss$', '', '')
   let link = substitute(link, '/show/', '/', '')
   return link
endfun

"" hotwired ----------------------------------------------------------
function! TareRssParseArticle_hotwired(url)
   call TareRssParseArticle_ste(a:url, 'cp932', '<!-- articles -->', '<!-- /articles -->')
endfun

"" Yahoo! ------------------------------------------------------------
function! TareRssParseArticle_YahooCom(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', '<!-- TextStart -->', '<!-- TextEnd -->')
endfun

function! TareRssParseLink_YahooCom(link, dummy)
   let link = substitute(a:link, '&amp;', '\&', 'g')
   let link = substitute(link, '.*/\*\(http://.*\)', '\1', '')
   return link
endfun

function! TareRssParseMode_YahooCom(mode, dummy)
   if a:mode == 0
      return 1
   endif
   return 0
endfun

" -------------------
" From My RSS
" -------------------

"" YahooJapan! -------------------------------------------------------
function! TareRssParseArticle_M_Yahoo(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', '<font size=5><b>', '"ǼĤˤʤΰո񤳤"')
endfun

function! TareRssParseFile_M_Yahoo(url, dummy)
   let url = substitute(a:url, '\v.*-(\d+-\w+-\w+)$', '\1', '')
   if url == a:url
      let url = ''
   endif
   return url
endfun

function! TareRssParseMode_M_Yahoo(mode, dummy)
   if a:mode == 0
      return 1
   endif
   return 0
endfun

" -------------------
" From bulknews
" -------------------

"" Internet Watch (bulknews) -----------------------------------------
function! TareRssParseArticle_b_InterW(url)
   call TareRssParseArticle_ste(a:url, 'cp932', '<!-- ֥ȥ  -->', '<!-- ʸλ -->')
endfun

function! TareRssParseDate_b_InterW(date, link)
   let date = substitute(a:link, '\v.*/(\d{4}/\d{2}/\d{2})/(\d+).html', '\1_\2', '')
   let date = substitute(date, '/', '-', 'g')
   return date
endfun

"" K-tai Watch (bulknews) --------------------------------------------
function! TareRssParseArticle_b_KtaiW(url)
   call TareRssParseArticle_ste(a:url, 'cp932', '<!-- ʸ -->', '<!-- ʸλ -->')
endfun

function! TareRssParseDate_b_KtaiW(date, link)
   let date = substitute(a:link, '\v.*/(\d+).html', '\1', '')
   return date
endfun

"" ITmedia (bulknews) ------------------------------------------------
function! TareRssParseArticle_b_ITmedia(url)
   call TareRssParseArticle_ste(a:url, 'cp932', '<!--֥ȥ饯-->', '<!--ʸλ-->')
endfun

function! TareRssParseDate_b_ITmedia(date, link)
   let date = substitute(a:link, '\v.*/(\d+)(\d{2})/(\d+)/news(\d+).html', '\1-\2-\3_\4', '')
   return date
endfun

"" Net Security (bulknews) -------------------------------------------
function! TareRssParseArticle_b_NetSec(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', '<TD valign="top" width="569">', ' contents end')
endfun

function! TareRssParseDate_b_NetSec(date, link)
   let date = substitute(a:link, '\v.*/(\d+).html', '\1', '')
   return date
endfun

" -------------------
" BLOG Service
" -------------------

"" hatena diary ------------------------------------------------------
function! TareRssParseArticle_hatena(url)
   let href = substitute(a:url, '\v.*/(\d+#.+)$', '\1', '')
   let name = substitute(a:url, '\v.*/\d+#(.+)$', '\1', '')
   call TareRssParseArticle_ste(a:url, 'euc-jp', 'a href="./'.href.'" name="'.name.'"', '</div>')
endfun

function! TareRssParseDate_hatena(date, link)
   let date = a:date
   if a:link =~ '\v.*/\d+#p\d+$'
      let link = substitute(a:link, '\v.*/\d+#p(\d+)$', '\1', '')
      let link = strlen(link) == 1 ? '0'.link : link
      let date = substitute(a:date, '00$', link, '')
   endif
   return date
endfun

function! TareRssParseFile_hatena(url, dummy)
   let anchor = substitute(a:url, '\v.*#(.{-})', '\1', '')
   return anchor
endfun

"" Jugem -------------------------------------------------------------
function! TareRssParseArticle_jugem(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', '<div class="entry_body">', '<div class="entry_state">')
endfun

function! TareRssParseDate_jugem(date, link)
   let date = a:date
   let date = substitute(date, '\v(\D)(\d)(\D)', '\1'.'0'.'\2\3', 'g')
   return date
endfun

"" cocolog -----------------------------------------------------------
function! TareRssParseArticle_cocolog(url)
   call TareRssParseArticle_ste(a:url, 'UTF-8', '/">ȥåץڡ</a>', '<p class="posted">')
endfun

"" Livedoor ----------------------------------------------------------
function! TareRssParseArticle_livedoor(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', 'class="title">', '<div class="posted">')
endfun

" -------------------
" BLOG Script
" -------------------

"" Movabletype -------------------------------------------------------
function! TareRssParseArticle_mova(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', ' class="title">', '<span class="posted">')
endfun

"" Movabletype UTF-8 -------------------------------------------------
function! TareRssParseArticle_movaU(url)
   call TareRssParseArticle_ste(a:url, 'UTF-8', ' class="title">', '<span class="posted">')
endfun

"" Movabletype 3 -----------------------------------------------------
function! TareRssParseArticle_mova3(url)
   call TareRssParseArticle_ste(a:url, 'UTF-8', ' class="content">', ' class="posted">')
endfun

"" tDiary ------------------------------------------------------------
function! TareRssParseArticle_tDiary(url)
   let name = substitute(a:url, '\v.*\d+[^/]*#(.+)$', '\1', '')
   call TareRssParseArticle_ste(a:url, 'euc-jp', 'a name="'.name.'"', '</div>')
endfun

function! TareRssParseDate_tDiary(date, link)
   let date = substitute(a:link, '\v.*(\d{4})(\d{2})(\d{2})[^/]*#.(\d+)', '\1-\2-\3_00:00:\4', '')
   if date == a:link || a:link =~ '\v#c\d+'
      let date = ''
   endif
   return date
endfun

function! TareRssParseFile_tDiary(url, dummy)
   let anchor = substitute(a:url, '\v.*#(.{-})', '\1', '')
   return anchor
endfun

"" blosxom -----------------------------------------------------------
function! TareRssParseArticle_blosxom(url)
   call TareRssParseArticle_ste(a:url, 'euc-jp', 'class="title">', '</div>')
endfun


